;;;; sqlite3-tinyclos-demo.scm
;;;; Small demonstration of the capabilities of sqlite3-tinyclos

;;; load extensions
(require-extension
  sqlite3 tinyclos sqlite3-tinyclos)

;;; create a database
(define db
  (sqlite3:open "test.db"))

(sqlite3:exec db
  "CREATE TABLE eggs(
	          name TEXT NOT NULL, license TEXT, is_module INTEGER NOT NULL DEFAULT 0,
		  PRIMARY KEY(name), CHECK(is_module IN (0, 1)));")

;;; define the object class
(sqlite3:define-stored-object-class db "eggs")

;;; add some data
(let ((egg (make <egg> "sqlite3")))
  ;; now the entry should already exist
  (print (sqlite3:in-store? egg))
  ;; let's add some data
  (set-license! egg "BSD")
  ;; and read it back
  (print (license egg))
  ;; other fields are filled with default data
  (print (module? egg))
  ;; changing the primary key is possible as well
  (sqlite3:set-pk! egg "foo")
  (print (sqlite3:pk egg))
  ;; which does not change data, of course
  (print (license egg))
  ;; and we can also delete the entry
  (print (sqlite3:remove-from-store! egg))
  ;; then it is gone
  (print (sqlite3:in-store? egg)))

;;;; vim:set shiftwidth=2 softtabstop=2: ;;;;
